==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/geode-management/src/test/java/org/apache/geode/management/api/EntityGroupInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.geode.management.api;

import static org.assertj.core.api.Assertions.assertThat;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.junit.Test;

import org.apache.geode.management.configuration.Region;
import org.apache.geode.management.runtime.RuntimeRegionInfo;
import org.apache.geode.util.internal.GeodeJsonMapper;

public class EntityGroupInfoTest {
  private ObjectMapper mapper = GeodeJsonMapper.getMapper();

  @Test
  public void jsonTest() throws Exception {
    EntityGroupInfo<Region, RuntimeRegionInfo> result = new EntityGroupInfo<>();
    Region region = new Region();
    region.setName("test");
    result.setConfiguration(region);

    String regionJson = mapper.writeValueAsString(region);
    String json = mapper.writeValueAsString(result);
    assertThat(regionJson).doesNotContain("links");
    System.out.println(json);
    assertThat(json).doesNotContain("links");
    mapper.readValue(json, EntityGroupInfo.class);
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-management/src/test/java/org/apache/geode/management/api/EntityGroupInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.geode.management.api;

import static org.assertj.core.api.Assertions.assertThat;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.junit.Test;

import org.apache.geode.management.configuration.Region;
import org.apache.geode.management.runtime.RuntimeRegionInfo;
import org.apache.geode.util.internal.GeodeJsonMapper;

public class EntityGroupInfoTest {
  private final ObjectMapper mapper = GeodeJsonMapper.getMapper();

  @Test
  public void jsonTest() throws Exception {
    EntityGroupInfo<Region, RuntimeRegionInfo> result = new EntityGroupInfo<>();
    Region region = new Region();
    region.setName("test");
    result.setConfiguration(region);

    String regionJson = mapper.writeValueAsString(region);
    String json = mapper.writeValueAsString(result);
    assertThat(regionJson).doesNotContain("links");
    System.out.println(json);
    assertThat(json).doesNotContain("links");
    mapper.readValue(json, EntityGroupInfo.class);
  }
}
